# Copyright 2020 Planet Labs, Inc.
# Copyright 2022 Planet Labs PBC.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Constants used across the code base"""
import os
from pathlib import Path

# NOTE: entries are given in alphabetical order

DATA_DIR = Path(os.path.dirname(__file__)) / 'data'

ENV_API_KEY = 'PL_API_KEY'

PLANET_BASE_URL = 'https://api.planet.com'

SECRET_FILE_PATH = Path(os.path.expanduser('~')) / '.planet.json'



from typing import Any, AsyncIterator, Coroutine, Iterator, TypeVar
from planet.http import Session

T = TypeVar("T")


class _BaseClient:

    def __init__(self, session: Session, base_url: str):
        """
        Parameters:
            session: Open session connected to server.
            base_url: The base URL to use. Defaults to production data API
                base url.
        """
        self._session = session

        self._base_url = base_url
        if self._base_url.endswith('/'):
            self._base_url = self._base_url[:-1]

    def _call_sync(self, f: Coroutine[Any, Any, T]) -> T:
        """block on an async function call, using the call_sync method of the session"""
        return self._session._call_sync(f)

    def _aiter_to_iter(self, aiter: AsyncIterator[T]) -> Iterator[T]:
        return self._session._aiter_to_iter(aiter)



# Copyright 2021 Planet Labs, Inc.
# Copyright 2022 Planet Labs PBC.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from .data import DataClient
from .features import FeaturesClient
from .orders import OrdersClient
from .subscriptions import SubscriptionsClient

__all__ = [
    'DataClient', 'FeaturesClient', 'OrdersClient', 'SubscriptionsClient'
]

# Organize client classes by their module name to allow lookup.
_client_directory = {
    'data': DataClient,
    'features': FeaturesClient,
    'orders': OrdersClient,
    'subscriptions': SubscriptionsClient
}
